﻿//-----------------------------------------------------------------------------
//	シリアルポートを使った Nucleo-F446 のコントロールの例
//		COM ポートを自動選択
//
//		マイコン側に "ON" または "OFF" を送る
//
//		マイコン側のプログラム： TrG_SerialComLed
//		ボーレート：9600 baud
//
//		作成者：三上直樹，2021/08/03 作成，©三上直樹 2021
//-----------------------------------------------------------------------------

using System;
using System.Windows.Forms;
using System.IO.Ports;
using Mikami.ComPort;

namespace CQ_SerialComLedAuto
{
	public partial class Form1 : Form
	{
		// シリアルポートと関連して使うクラスのオブジェクト
		private readonly MySerialPort sp_;
		// COM ポートの自動選択で使うクラスのオブジェクト
		private readonly AutoSelect comAuto_;

		private string rxData_ = "";	// 受信データ用バッファ

		public Form1()
		{
			InitializeComponent();

			sp_ = new MySerialPort(serialPort1);
			comAuto_ = new AutoSelect("LED_CTRLer", sp_, toolStripLabel1);
		}

		// 点滅処理を有効にするための指令を送信する
		private void radioButton1_Click(object sender, EventArgs e)
		{	sp_.SendTo("ON");	}

		// 点滅処理を無効にするための指令を送信する
		private void radioButton2_Click(object sender, EventArgs e)
		{	sp_.SendTo("OFF");	}

		// 終了時に シリアルポートがオープンであればクローズする
		private void Form1_FormClosing(object sender, FormClosingEventArgs e)
		{
			try { if (serialPort1.IsOpen) serialPort1.Close(); }
			catch (Exception ex) { sp_.ExceptionCatch(ex); }
		}

		// データ受信イベントに対応するハンドラ
		private void serialPort1_DataReceived(object sender, SerialDataReceivedEventArgs e)
		{
			try {
				rxData_ = serialPort1.ReadLine();
				if (rxData_ == "ACK")
				{
					comAuto_.StopTimer();
					toolStripLabel1.Text = "マイコン側の準備ができました．";
					toolStripLabel2.Text = " " + serialPort1.PortName + " ";
					Invoke(() => panel1.Enabled = true);
				}
				else
					Reply();	// "ACK" 受信以外の処理
			}
			catch (Exception ex) { sp_.ExceptionCatch(ex); }
		}

		// 送信したデータに対する応答
		private void Reply()
			=> Invoke(() => label1.Text = "LED 点滅： " + rxData_);

		//--------------------------------------------------------------
		// 別のスレッドを使う場合に使用
		private void Invoke(Action action) => base.Invoke(action);
	}
}
